==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/NativeUISlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUISlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUISlider, _super);
    function NativeUISlider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.bi = null;
        _this.bj = null;
        return _this;
    }
    NativeUISlider.prototype.get_e = function () {
        return 5;
    };
    Object.defineProperty(NativeUISlider.prototype, "bp", {
        get: function () {
            var a = this.ag(2);
            return a;
        },
        set: function (a) {
            this.a2(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bn", {
        get: function () {
            var a = this.ag(12);
            return a;
        },
        set: function (a) {
            this.a2(12, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bm", {
        get: function () {
            var a = this.ag(13);
            return a;
        },
        set: function (a) {
            this.a2(13, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bo", {
        get: function () {
            var a = this.ag(14);
            return a;
        },
        set: function (a) {
            this.a2(14, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bk", {
        get: function () {
            return this.bi;
        },
        set: function (a) {
            var b = this.bi;
            this.bi = a;
            if (this.bi != b) {
                if (b != null) {
                    this.a0(4, b);
                }
                if (this.bi != null) {
                    this.ap(4, this.bi);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bl", {
        get: function () {
            return this.bj;
        },
        set: function (a) {
            var b = this.bj;
            this.bj = a;
            if (this.bj != b) {
                if (b != null) {
                    this.a0(0, b);
                }
                if (this.bj != null) {
                    this.ap(0, this.bj);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUISlider.$t = markType(NativeUISlider, 'NativeUISlider', NativeUIComponent.$);
    return NativeUISlider;
}(NativeUIComponent));
export { NativeUISlider };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/NativeUISlider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { enumGetBox, EnumUtil, markType } from "./type";
import { NativeUISliderOrientation_$type } from "./NativeUISliderOrientation";
/**
 * @hidden
 */
var NativeUISlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUISlider, _super);
    function NativeUISlider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.bl = null;
        _this.bm = null;
        return _this;
    }
    NativeUISlider.prototype.get_e = function () {
        return 5;
    };
    Object.defineProperty(NativeUISlider.prototype, "bs", {
        get: function () {
            var a = this.ag(2);
            return a;
        },
        set: function (a) {
            this.a4(2, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bq", {
        get: function () {
            var a = this.ag(12);
            return a;
        },
        set: function (a) {
            this.a4(12, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bu", {
        get: function () {
            var a = this.ag(94);
            return a;
        },
        set: function (a) {
            this.a4(94, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bv", {
        get: function () {
            var a = this.ag(89);
            return a;
        },
        set: function (a) {
            this.a4(89, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bx", {
        get: function () {
            var a = this.ag(91);
            return a;
        },
        set: function (a) {
            this.a4(91, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bz", {
        get: function () {
            var a = this.ag(93);
            return a;
        },
        set: function (a) {
            this.a4(93, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "by", {
        get: function () {
            var a = this.ag(92);
            return a;
        },
        set: function (a) {
            this.a4(92, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bw", {
        get: function () {
            var a = this.ag(90);
            return a;
        },
        set: function (a) {
            this.a4(90, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bk", {
        get: function () {
            var a = this.ag(30);
            return EnumUtil.getEnumValue(NativeUISliderOrientation_$type, a);
        },
        set: function (a) {
            this.a4(30, enumGetBox(NativeUISliderOrientation_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bp", {
        get: function () {
            var a = this.ag(13);
            return a;
        },
        set: function (a) {
            this.a4(13, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bt", {
        get: function () {
            var a = this.ag(95);
            return a;
        },
        set: function (a) {
            this.a4(95, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "br", {
        get: function () {
            var a = this.ag(14);
            return a;
        },
        set: function (a) {
            this.a4(14, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bn", {
        get: function () {
            return this.bl;
        },
        set: function (a) {
            var b = this.bl;
            this.bl = a;
            if (this.bl != b) {
                if (b != null) {
                    this.a2(4, b);
                }
                if (this.bl != null) {
                    this.aq(4, this.bl);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUISlider.prototype, "bo", {
        get: function () {
            return this.bm;
        },
        set: function (a) {
            var b = this.bm;
            this.bm = a;
            if (this.bm != b) {
                if (b != null) {
                    this.a2(0, b);
                }
                if (this.bm != null) {
                    this.aq(0, this.bm);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUISlider.$t = markType(NativeUISlider, 'NativeUISlider', NativeUIComponent.$);
    return NativeUISlider;
}(NativeUIComponent));
export { NativeUISlider };
